@@ -1,28 +1,14 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Reginald Stadlbauer <reggie@kde.org>
 
-   Copyright (C) 1999 Reginald Stadlbauer <reggie@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef kcharselect_h
 #define kcharselect_h
 
 #include <QString>
-#include <QStringList>
 #include <QWidget>
 #include <kwidgetsaddons_export.h>
 
@@ -71,7 +57,6 @@ class QUrl;
  * @author Reginald Stadlbauer <reggie@kde.org>
  * @author Daniel Laidig <d.laidig@gmx.de>
  */
-
 class KWIDGETSADDONS_EXPORT KCharSelect : public QWidget
 {
     Q_OBJECT
@@ -85,6 +70,7 @@ class KWIDGETSADDONS_EXPORT KCharSelect : public QWidget
 public:
     /**
      * Flags to set the shown widgets
+     * @see Controls
      */
     enum Control {
         /**
@@ -120,6 +106,9 @@ public:
          */
         AllGuiElements      = 65535
     };
+    /**
+     * Stores a combination of #Control values.
+     */
     Q_DECLARE_FLAGS(Controls,
                     Control)
 
