@@ -1,22 +1,10 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1997 Martin Jones (mjones@kde.org)
-    Copyright (C) 2007 Pino Toscano (pino@kde.org)
-    Copyright (c) 2007 David Jarvie (djarvie@kde.org)
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1997 Martin Jones <mjones@kde.org>
+    SPDX-FileCopyrightText: 2007 Pino Toscano <pino@kde.org>
+    SPDX-FileCopyrightText: 2007 David Jarvie <djarvie@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kcolorcombo.h"
