@@ -1,20 +1,7 @@
 /*
-    Copyright 2011 John Layt <john@layt.net>
+    SPDX-FileCopyrightText: 2011 John Layt <john@layt.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KDATETIMEEDIT_H
@@ -28,6 +15,11 @@
 
 class KDateTimeEditPrivate;
 
+/**
+ * @class KDateTimeEdit kdatetimeedit.h KDateTimeEdit
+ *
+ * @short A widget for editing date and time.
+ */
 class KWIDGETSADDONS_EXPORT KDateTimeEdit : public QWidget
 {
     Q_OBJECT
@@ -43,6 +35,7 @@ public:
      * Options provided by the widget
      * @see options
      * @see setOptions
+     * @see Options
      */
     enum Option {
         ShowCalendar     = 0x00001,  /**< If the Calendar System edit is displayed */
@@ -62,18 +55,21 @@ public:
         ForceTime        = 0x04000,  /**< The entered time can only be a selected time */
         WarnOnInvalid    = 0x08000   /**< Show a warning on focus out if the date or time is invalid */
     };
+    /**
+     * Stores a combination of #Option values.
+     */
     Q_DECLARE_FLAGS(Options, Option)
     Q_FLAG(Options)
 
     /**
      * Create a new KDateTimeEdit widget
      */
-    explicit KDateTimeEdit(QWidget *parent = 0);
+    explicit KDateTimeEdit(QWidget *parent = nullptr);
 
     /**
      * Destroy the widget
      */
-    virtual ~KDateTimeEdit();
+    ~KDateTimeEdit() override;
 
     /**
      * Return the currently set widget options
@@ -111,9 +107,9 @@ public:
     QTimeZone timeZone() const;
 
     /**
-     * Returns the list of Calendar Systems displayed.
+     * Returns the list of Calendar Locales displayed.
      *
-     * @param calendars the list of calendar systems to display
+     * @return the list of calendar locales displayed
      */
     QList<QLocale> calendarLocalesList() const;
 
@@ -144,8 +140,9 @@ public:
      * Return the map of dates listed in the drop-down and their displayed
      * string forms.
      *
-     * @see setDateMap()
      * @return the select date map
+     *
+     * @see setDateMap()
      */
     QMap<QDate, QString> dateMap() const;
 
@@ -168,17 +165,18 @@ public:
     /**
      * Return the list of times able to be selected in the drop-down.
      *
+     * @return the select time list
+     *
      * @see setTimeList()
      * @see timeListInterval()
      * @see setTimeListInterval()
-     * @return the select time list
      */
     QList<QTime> timeList() const;
 
     /**
      * Return the list of time zones able to be selected
      *
-     * @param zones the time zones to display
+     * @return the list of time zones displayed
      */
     QList<QTimeZone> timeZones() const;
 
@@ -187,16 +185,18 @@ public:
      *
      * If the user input is null then it is not valid
      *
-     * @see isNull()
      * @return if the current user input is valid
+     *
+     * @see isNull()
      */
     bool isValid() const;
 
     /**
      * Return if the current user input is null
      *
-     * @see isValid()
      * @return if the current user input is null
+     *
+     * @see isValid()
      */
     bool isNull() const;
 
@@ -205,16 +205,18 @@ public:
      *
      * If the user input date is null then it is not valid
      *
-     * @see isNullDate()
      * @return if the current user input date is valid
+     *
+     * @see isNullDate()
      */
     bool isValidDate() const;
 
     /**
      * Return if the current user input date is null
      *
-     * @see isValidDate()
      * @return if the current user input date is null
+     *
+     * @see isValidDate()
      */
     bool isNullDate() const;
     /**
@@ -222,16 +224,18 @@ public:
      *
      * If the user input time is null then it is not valid
      *
-     * @see isNullTime()
      * @return if the current user input time is valid
+     *
+     * @see isNullTime()
      */
     bool isValidTime() const;
 
     /**
      * Return if the current user input time is null
      *
-     * @see isValidTime()
      * @return if the current user input time is null
+     *
+     * @see isValidTime()
      */
     bool isNullTime() const;
 
@@ -339,7 +343,7 @@ Q_SIGNALS:
     /**
      * Signal if the time zone has been changed manually by the user.
      *
-     * @param timeZone the new time zone
+     * @param zone the new time zone
      */
     void timeZoneEntered(const QTimeZone &zone);
 
@@ -347,7 +351,7 @@ Q_SIGNALS:
      * Signal if the time zone has been changed either manually by the user
      * or programatically.
      *
-     * @param timeZone the new time zone
+     * @param zone the new time zone
      */
     void timeZoneChanged(const QTimeZone &zone);
 
@@ -416,10 +420,11 @@ public Q_SLOTS:
      * If the date is invalid, or more than current maximum,
      * then the minimum will not be set.
      *
+     * @param minDateTime the minimum date
+     * @param minWarnMsg the minimum warning message
+     *
      * @see setMaximumDateTime()
      * @see setDateRange()
-     * @param maxDate the minimum date
-     * @param maxWarnMsg the minimum warning message
      */
     void setMinimumDateTime(const QDateTime &minDateTime, const QString &minWarnMsg = QString());
 
@@ -434,10 +439,11 @@ public Q_SLOTS:
      * If the date is invalid, or less than current minimum,
      * then the maximum will not be set.
      *
+     * @param maxDateTime the maximum date
+     * @param maxWarnMsg the maximum warning message
+     *
      * @see setMinimumDateTime()
      * @see setDateRange()
-     * @param maxDate the maximum date
-     * @param maxWarnMsg the maximum warning message
      */
     void setMaximumDateTime(const QDateTime &maxDateTime, const QString &maxWarnMsg = QString());
 
@@ -474,8 +480,9 @@ public Q_SLOTS:
      * default date format then the string should be null.  If you want a
      * separator to be displayed then set the string to "separator".
      *
-     * @see dateMap()
      * @param dateMap the map of dates able to be selected
+     *
+     * @see dateMap()
      */
     void setDateMap(QMap<QDate, QString> dateMap);
 
@@ -486,12 +493,12 @@ public Q_SLOTS:
      *
      * @param format the time format to use
      */
-    void setTimeDisplayFormat(QLocale::FormatType formatOptions);
+    void setTimeDisplayFormat(QLocale::FormatType format);
 
     /**
      * Set the interval between times able to be selected from the drop-down.
      *
-     * The combo drop-down will be populated with times every @param minutes
+     * The combo drop-down will be populated with times every @p minutes
      * apart, starting from the minimumTime() and ending at maximumTime().
      *
      * If the ForceInterval option is set then any time manually typed into the
@@ -504,8 +511,9 @@ public Q_SLOTS:
      * Setting the time list interval will override any time list previously set
      * via setTimeList().
      *
-     * @see timeListInterval()
      * @param minutes the time list interval to display
+     *
+     * @see timeListInterval()
      */
     void setTimeListInterval(int minutes);
 
@@ -521,10 +529,11 @@ public Q_SLOTS:
      * The minimum and maximum time will automatically be set to the earliest
      * and latest value in the list.
      *
-     * @see timeList()
      * @param timeList the list of times able to be selected
      * @param minWarnMsg the minimum warning message
      * @param maxWarnMsg the maximum warning message
+     *
+     * @see timeList()
      */
     void setTimeList(QList<QTime> timeList,
                      const QString &minWarnMsg = QString(),
@@ -539,10 +548,10 @@ public Q_SLOTS:
 
 protected:
 
-    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
-    void focusInEvent(QFocusEvent *event) Q_DECL_OVERRIDE;
-    void focusOutEvent(QFocusEvent *event) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *object, QEvent *event) override;
+    void focusInEvent(QFocusEvent *event) override;
+    void focusOutEvent(QFocusEvent *event) override;
+    void resizeEvent(QResizeEvent *event) override;
 
     /**
      * Assign the date, time and time zone for the widget.
@@ -550,7 +559,7 @@ protected:
      * Virtual to allow sub-classes to apply extra validation rules,
      * but reimplementations must call the parent method at the end.
      *
-     * @param datetime the new date and time
+     * @param dateTime the new date and time
      */
     virtual void assignDateTime(const QDateTime &dateTime);
 
