@@ -1,22 +1,11 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2000 David Faure <faure@kde.org>, Alexander Neundorf <neundorf@kde.org>
-             (C) 2000, 2002 Carsten Pfeiffer <pfeiffer@kde.org>
-             (C) 2010 Sebastian Trueg <trueg@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000 Alexander Neundorf <neundorf@kde.org>
+    SPDX-FileCopyrightText: 2000, 2002 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2010 Sebastian Trueg <trueg@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "keditlistwidget.h"
@@ -36,9 +25,7 @@ class KEditListWidgetPrivate
 {
 public:
     KEditListWidgetPrivate(KEditListWidget *parent)
-        : lineEdit(nullptr),
-          editingWidget(nullptr),
-          q(parent)
+        : q(parent)
     {
     }
     QListView *listView = nullptr;
@@ -62,7 +49,7 @@ public:
     QModelIndex selectedIndex();
 
 private:
-    KEditListWidget *q;
+    KEditListWidget *const q;
 };
 
 void KEditListWidgetPrivate::init(bool check, KEditListWidget::Buttons newButtons,
@@ -81,14 +68,14 @@ void KEditListWidgetPrivate::init(bool check, KEditListWidget::Buttons newButton
     btnsLayout = new QVBoxLayout;
     btnsLayout->addStretch();
 
-    model = new QStringListModel();
+    model = new QStringListModel(q);
     listView = new QListView(q);
     listView->setModel(model);
 
     subLayout->addWidget(listView);
     subLayout->addLayout(btnsLayout);
 
-    mainLayout->insertLayout(1, subLayout);
+    mainLayout->addLayout(subLayout);
 
     setEditor(lineEdit, representationWidget);
 
@@ -116,7 +103,7 @@ void KEditListWidgetPrivate::setEditor(QLineEdit *newLineEdit, QWidget *represen
         representationWidget->setParent(q);
     }
 
-    mainLayout->insertWidget(0, editingWidget);
+    mainLayout->insertWidget(0, editingWidget); // before subLayout
 
     lineEdit->installEventFilter(q);
 
@@ -302,7 +289,7 @@ void KEditListWidget::setButtons(Buttons buttons)
     }
 
     if ((buttons & Add) && !d->servNewButton) {
-        d->servNewButton = new QPushButton(QIcon::fromTheme(QStringLiteral("list-add")), tr("&Add"), this);
+        d->servNewButton = new QPushButton(QIcon::fromTheme(QStringLiteral("list-add")), tr("&Add", "@action:button"), this);
         d->servNewButton->setEnabled(false);
         d->servNewButton->show();
         connect(d->servNewButton, &QAbstractButton::clicked, this, &KEditListWidget::addItem);
@@ -314,7 +301,7 @@ void KEditListWidget::setButtons(Buttons buttons)
     }
 
     if ((buttons & Remove) && !d->servRemoveButton) {
-        d->servRemoveButton = new QPushButton(QIcon::fromTheme(QStringLiteral("list-remove")), tr("&Remove"), this);
+        d->servRemoveButton = new QPushButton(QIcon::fromTheme(QStringLiteral("list-remove")), tr("&Remove", "@action:button"), this);
         d->servRemoveButton->setEnabled(false);
         d->servRemoveButton->show();
         connect(d->servRemoveButton, &QAbstractButton::clicked, this, &KEditListWidget::removeItem);
@@ -326,12 +313,12 @@ void KEditListWidget::setButtons(Buttons buttons)
     }
 
     if ((buttons & UpDown) && !d->servUpButton) {
-        d->servUpButton = new QPushButton(QIcon::fromTheme(QStringLiteral("arrow-up")), tr("Move &Up"), this);
+        d->servUpButton = new QPushButton(QIcon::fromTheme(QStringLiteral("arrow-up")), tr("Move &Up", "@action:button"), this);
         d->servUpButton->setEnabled(false);
         d->servUpButton->show();
         connect(d->servUpButton, &QAbstractButton::clicked, this, &KEditListWidget::moveItemUp);
 
-        d->servDownButton = new QPushButton(QIcon::fromTheme(QStringLiteral("arrow-down")), tr("Move &Down"), this);
+        d->servDownButton = new QPushButton(QIcon::fromTheme(QStringLiteral("arrow-down")), tr("Move &Down", "@action:button"), this);
         d->servDownButton->setEnabled(false);
         d->servDownButton->show();
         connect(d->servDownButton, &QAbstractButton::clicked, this, &KEditListWidget::moveItemDown);
