@@ -1,29 +1,18 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1999 Reginald Stadlbauer <reggie@kde.org>
-              (C) 1999 Simon Hausmann <hausmann@kde.org>
-              (C) 2000 Nicolas Hadacek <haadcek@kde.org>
-              (C) 2000 Kurt Granroth <granroth@kde.org>
-              (C) 2000 Michael Koch <koch@kde.org>
-              (C) 2001 Holger Freyther <freyther@kde.org>
-              (C) 2002 Ellis Whitehead <ellis@kde.org>
-              (C) 2002 Joseph Wenninger <jowenn@kde.org>
-              (C) 2003 Andras Mantia <amantia@kde.org>
-              (C) 2005-2006 Hamish Rodda <rodda@kde.org>
-              (C) 2007 Clarence Dang <dang@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000 Nicolas Hadacek <haadcek@kde.org>
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2000 Michael Koch <koch@kde.org>
+    SPDX-FileCopyrightText: 2001 Holger Freyther <freyther@kde.org>
+    SPDX-FileCopyrightText: 2002 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2002 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2003 Andras Mantia <amantia@kde.org>
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007 Clarence Dang <dang@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kfontaction.h"
@@ -36,9 +25,7 @@ class Q_DECL_HIDDEN KFontAction::KFontActionPrivate
 {
 public:
     KFontActionPrivate(KFontAction *parent)
-        : q(parent),
-          settingFont(0),
-          fontFilters(QFontComboBox::AllFonts)
+        : q(parent)
     {
     }
 
@@ -50,15 +37,19 @@ public:
             return;
         }
 
-        q->setFont(font.family());
-        emit q->triggered(font.family());
+        const QString fontFamily = font.family();
+        q->setFont(fontFamily);
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 78)
+        emit q->triggered(fontFamily);
+#endif
+        emit q->textTriggered(fontFamily);
 
 //        qCDebug(KWidgetsAddonsLog) << "\tslotFontChanged done";
     }
 
-    KFontAction *q;
-    int settingFont;
-    QFontComboBox::FontFilters fontFilters;
+    KFontAction *const q;
+    int settingFont = 0;
+    QFontComboBox::FontFilters fontFilters = QFontComboBox::AllFonts;
 };
 
 QStringList _k_fontList(const QFontComboBox::FontFilters &fontFilters = QFontComboBox::AllFonts)
@@ -142,9 +133,7 @@ QString KFontAction::font() const
 QWidget *KFontAction::createWidget(QWidget *parent)
 {
 //    qCDebug(KWidgetsAddonsLog) << "KFontAction::createWidget()";
-#ifdef __GNUC__
-#warning FIXME: items need to be converted
-#endif
+
     // This is the visual element on the screen.  This method overrides
     // the KSelectAction one, preventing KSelectAction from creating its
     // regular KComboBox.
