@@ -1,22 +1,9 @@
 /*
-Copyright (C) 1996 Bernd Johannes Wuebben  <wuebben@kde.org>
-Copyright (c) 1999 Preston Brown <pbrown@kde.org>
-Copyright (c) 1999 Mario Weilguni <mweilguni@kde.org>
+    SPDX-FileCopyrightText: 1996 Bernd Johannes Wuebben <wuebben@kde.org>
+    SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
+    SPDX-FileCopyrightText: 1999 Mario Weilguni <mweilguni@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public License
-along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kfontchooser.h"
@@ -93,6 +80,8 @@ public:
     // inserted into the fontdialog font-family combo-box
 //    QStringList  fontList;
 
+    void init(const DisplayFlags &flags, const QStringList &fontList,
+              int visibleListSize, Qt::CheckState *sizeIsRelativeState);
     void setFamilyBoxItems(const QStringList &fonts);
     void fillFamilyListBox(bool onlyFixedFonts = false);
     int nearestSizeRow(qreal val, bool customize);
@@ -102,7 +91,6 @@ public:
     void setupDisplay();
     QString styleIdentifier(const QFont &font);
 
-    void _k_toggled_checkbox();
     void _k_family_chosen_slot(const QString &);
     void _k_size_chosen_slot(const QString &);
     void _k_style_chosen_slot(const QString &);
@@ -128,6 +116,8 @@ public:
     QListWidget     *sizeListBox = nullptr;
     QCheckBox    *sizeIsRelativeCheckBox = nullptr;
 
+    QCheckBox *onlyFixedCheckbox = nullptr;
+
     QFont        selFont;
 
     QString      selectedStyle;
@@ -156,256 +146,7 @@ KFontChooser::KFontChooser(QWidget *parent,
     : QWidget(parent),
       d(new KFontChooser::Private(this))
 {
-    d->usingFixed = flags & FixedFontsOnly;
-    setWhatsThis(KFontChooser::tr("Here you can choose the font to be used.", "@info:whatsthis"));
-
-    // The top layout is divided vertically into a splitter with font
-    // attribute widgets and preview on the top, and XLFD data at the bottom.
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
-    topLayout->setContentsMargins(0, 0, 0, 0);
-    const int spacingHint = style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
-    int checkBoxGap = spacingHint / 2;
-
-    // The splitter contains font attribute widgets in the top part,
-    // and the font preview in the bottom part.
-    // The splitter is there to allow the user to resize the font preview.
-    QSplitter *splitter = new QSplitter(Qt::Vertical, this);
-    splitter->setChildrenCollapsible(false);
-    topLayout->addWidget(splitter);
-
-    // Build the grid of font attribute widgets for the upper splitter part.
-    //
-    QWidget *page;
-    QGridLayout *gridLayout;
-    int row = 0;
-    if (flags & DisplayFrame) {
-        page = new QGroupBox(KFontChooser::tr("Requested Font"), this);
-        splitter->addWidget(page);
-        gridLayout = new QGridLayout(page);
-        row = 1;
-    } else {
-        page = new QWidget(this);
-        splitter->addWidget(page);
-        gridLayout = new QGridLayout(page);
-        gridLayout->setContentsMargins(0, 0, 0, 0);
-    }
-
-    //
-    // first, create the labels across the top
-    //
-    QHBoxLayout *familyLayout = new QHBoxLayout();
-    familyLayout->addSpacing(checkBoxGap);
-    if (flags & ShowDifferences) {
-        d->familyCheckbox = new QCheckBox(KFontChooser::tr("Font", "@option:check"), page);
-        connect(d->familyCheckbox, SIGNAL(toggled(bool)),
-                this, SLOT(_k_toggled_checkbox()));
-        familyLayout->addWidget(d->familyCheckbox, 0, Qt::AlignLeft);
-        d->familyCheckbox->setWhatsThis(KFontChooser::tr("Enable this checkbox to change the font family settings.", "@info:whatsthis"));
-        d->familyCheckbox->setToolTip(KFontChooser::tr("Change font family?", "@info:tooltip"));
-        d->familyLabel = nullptr;
-    } else {
-        d->familyCheckbox = nullptr;
-        d->familyLabel = new QLabel(KFontChooser::tr("Font:", "@label"), page);
-        familyLayout->addWidget(d->familyLabel, 1, Qt::AlignLeft);
-    }
-    gridLayout->addLayout(familyLayout, row, 0);
-
-    QHBoxLayout *styleLayout = new QHBoxLayout();
-    if (flags & ShowDifferences) {
-        d->styleCheckbox = new QCheckBox(KFontChooser::tr("Font style", "@option:check"), page);
-        connect(d->styleCheckbox, SIGNAL(toggled(bool)),
-                this, SLOT(_k_toggled_checkbox()));
-        styleLayout->addWidget(d->styleCheckbox, 0, Qt::AlignLeft);
-        d->styleCheckbox->setWhatsThis(KFontChooser::tr("Enable this checkbox to change the font style settings.", "@info:whatsthis"));
-        d->styleCheckbox->setToolTip(KFontChooser::tr("Change font style?", "@info:tooltip"));
-        d->styleLabel = nullptr;
-    } else {
-        d->styleCheckbox = nullptr;
-        d->styleLabel = new QLabel(KFontChooser::tr("Font style:"), page);
-        styleLayout->addWidget(d->styleLabel, 1, Qt::AlignLeft);
-    }
-    styleLayout->addSpacing(checkBoxGap);
-    gridLayout->addLayout(styleLayout, row, 1);
-
-    QHBoxLayout *sizeLayout = new QHBoxLayout();
-    if (flags & ShowDifferences) {
-        d->sizeCheckbox = new QCheckBox(KFontChooser::tr("Size", "@option:check"), page);
-        connect(d->sizeCheckbox, SIGNAL(toggled(bool)),
-                this, SLOT(_k_toggled_checkbox()));
-        sizeLayout->addWidget(d->sizeCheckbox, 0, Qt::AlignLeft);
-        d->sizeCheckbox->setWhatsThis(KFontChooser::tr("Enable this checkbox to change the font size settings.", "@info:whatsthis"));
-        d->sizeCheckbox->setToolTip(KFontChooser::tr("Change font size?", "@info:tooltip"));
-        d->sizeLabel = nullptr;
-    } else {
-        d->sizeCheckbox = nullptr;
-        d->sizeLabel = new QLabel(KFontChooser::tr("Size:", "@label:listbox Font size"), page);
-        sizeLayout->addWidget(d->sizeLabel, 1, Qt::AlignLeft);
-    }
-    sizeLayout->addSpacing(checkBoxGap);
-    sizeLayout->addSpacing(checkBoxGap);   // prevent label from eating border
-    gridLayout->addLayout(sizeLayout, row, 2);
-
-    row ++;
-
-    //
-    // now create the actual boxes that hold the info
-    //
-    d->familyListBox = new QListWidget(page);
-    d->familyListBox->setEnabled(flags ^ ShowDifferences);
-    gridLayout->addWidget(d->familyListBox, row, 0);
-    QString fontFamilyWhatsThisText(
-        KFontChooser::tr("Here you can choose the font family to be used.", "@info:whatsthis"));
-    d->familyListBox->setWhatsThis(fontFamilyWhatsThisText);
-
-    if (flags & ShowDifferences) {
-        d->familyCheckbox->setWhatsThis(fontFamilyWhatsThisText);
-    } else {
-        d->familyLabel->setWhatsThis(fontFamilyWhatsThisText);
-    }
-
-    connect(d->familyListBox, SIGNAL(currentTextChanged(QString)),
-            this, SLOT(_k_family_chosen_slot(QString)));
-    if (!fontList.isEmpty()) {
-        d->setFamilyBoxItems(fontList);
-    } else {
-        d->fillFamilyListBox(flags & FixedFontsOnly);
-    }
-
-    d->familyListBox->setMinimumWidth(minimumListWidth(d->familyListBox));
-    d->familyListBox->setMinimumHeight(
-        minimumListHeight(d->familyListBox, visibleListSize));
-
-    d->styleListBox = new QListWidget(page);
-    d->styleListBox->setEnabled(flags ^ ShowDifferences);
-    gridLayout->addWidget(d->styleListBox, row, 1);
-    d->styleListBox->setWhatsThis(KFontChooser::tr("Here you can choose the font style to be used.", "@info:whatsthis"));
-    if (flags & ShowDifferences) {
-        ((QWidget *)d->styleCheckbox)->setWhatsThis(fontFamilyWhatsThisText);
-    } else {
-        ((QWidget *)d->styleLabel)->setWhatsThis(fontFamilyWhatsThisText);
-    }
-    // Populate usual styles, to determine minimum list width;
-    // will be replaced later with correct styles.
-    d->styleListBox->addItem(KFontChooser::tr("Normal", "QFontDatabase"));
-    d->styleListBox->addItem(KFontChooser::tr("Italic", "@item font"));
-    d->styleListBox->addItem(KFontChooser::tr("Oblique", "@item font"));
-    d->styleListBox->addItem(KFontChooser::tr("Bold", "@item font"));
-    d->styleListBox->addItem(KFontChooser::tr("Bold Italic", "@item font"));
-    d->styleListBox->setMinimumWidth(minimumListWidth(d->styleListBox));
-    d->styleListBox->setMinimumHeight(
-        minimumListHeight(d->styleListBox, visibleListSize));
-
-    connect(d->styleListBox, SIGNAL(currentTextChanged(QString)),
-            this, SLOT(_k_style_chosen_slot(QString)));
-
-    d->sizeListBox = new QListWidget(page);
-    d->sizeOfFont = new QDoubleSpinBox(page);
-    d->sizeOfFont->setMinimum(4);
-    d->sizeOfFont->setMaximum(999);
-    d->sizeOfFont->setDecimals(1);
-    d->sizeOfFont->setSingleStep(1);
-
-    d->sizeListBox->setEnabled(flags ^ ShowDifferences);
-    d->sizeOfFont->setEnabled(flags ^ ShowDifferences);
-    if (sizeIsRelativeState) {
-        QString sizeIsRelativeCBText =
-            KFontChooser::tr("Relative", "@item font size");
-        QString sizeIsRelativeCBToolTipText =
-            KFontChooser::tr("Font size<br /><i>fixed</i> or <i>relative</i><br />to environment");
-        QString sizeIsRelativeCBWhatsThisText =
-            KFontChooser::tr("Here you can switch between fixed font size and font size "
-               "to be calculated dynamically and adjusted to changing "
-               "environment (e.g. widget dimensions, paper size).");
-        d->sizeIsRelativeCheckBox = new QCheckBox(sizeIsRelativeCBText,
-                page);
-        d->sizeIsRelativeCheckBox->setTristate(flags & ShowDifferences);
-        QGridLayout *sizeLayout2 = new QGridLayout();
-        sizeLayout2->setSpacing(spacingHint / 2);
-        gridLayout->addLayout(sizeLayout2, row, 2);
-        sizeLayout2->setColumnStretch(1, 1);   // to prevent text from eating the right border
-        sizeLayout2->addWidget(d->sizeOfFont, 0, 0, 1, 2);
-        sizeLayout2->addWidget(d->sizeListBox, 1, 0, 1, 2);
-        sizeLayout2->addWidget(d->sizeIsRelativeCheckBox, 2, 0, Qt::AlignLeft);
-        d->sizeIsRelativeCheckBox->setWhatsThis(sizeIsRelativeCBWhatsThisText);
-        d->sizeIsRelativeCheckBox->setToolTip(sizeIsRelativeCBToolTipText);
-    } else {
-        d->sizeIsRelativeCheckBox = nullptr;
-        QGridLayout *sizeLayout2 = new QGridLayout();
-        sizeLayout2->setSpacing(spacingHint / 2);
-        gridLayout->addLayout(sizeLayout2, row, 2);
-        sizeLayout2->addWidget(d->sizeOfFont, 0, 0);
-        sizeLayout2->addWidget(d->sizeListBox, 1, 0);
-    }
-    QString fontSizeWhatsThisText =
-        KFontChooser::tr("Here you can choose the font size to be used.");
-    d->sizeListBox->setWhatsThis(fontSizeWhatsThisText);
-
-    if (flags & ShowDifferences) {
-        ((QWidget *)d->sizeCheckbox)->setWhatsThis(fontSizeWhatsThisText);
-    } else {
-        ((QWidget *)d->sizeLabel)->setWhatsThis(fontSizeWhatsThisText);
-    }
-
-    // Populate with usual sizes, to determine minimum list width;
-    // will be replaced later with correct sizes.
-    d->fillSizeList();
-    d->sizeListBox->setMinimumWidth(minimumListWidth(d->sizeListBox) +
-                                    d->sizeListBox->fontMetrics().maxWidth());
-    d->sizeListBox->setMinimumHeight(
-        minimumListHeight(d->sizeListBox, visibleListSize));
-
-    connect(d->sizeOfFont, SIGNAL(valueChanged(double)),
-            this, SLOT(_k_size_value_slot(double)));
-
-    connect(d->sizeListBox, SIGNAL(currentTextChanged(QString)),
-            this, SLOT(_k_size_chosen_slot(QString)));
-
-    row ++;
-    //
-    // Completed the font attribute grid.
-
-    // Add the font preview into the lower part of the splitter.
-    //
-    d->sampleEdit = new QTextEdit(page);
-    d->sampleEdit->setAcceptRichText(false);
-    QFont tmpFont(font().family(), 64, QFont::Black);
-    d->sampleEdit->setFont(tmpFont);
-    d->sampleEdit->setMinimumHeight(d->sampleEdit->fontMetrics().lineSpacing());
-    // tr: A classical test phrase, with all letters of the English alphabet.
-    // Replace it with a sample text in your language, such that it is
-    // representative of language's writing system.
-    // If you wish, you can input several lines of text separated by \n.
-    setSampleText(KFontChooser::tr("The Quick Brown Fox Jumps Over The Lazy Dog"));
-    d->sampleEdit->setTextCursor(QTextCursor(d->sampleEdit->document()));
-    QString sampleEditWhatsThisText =
-        KFontChooser::tr("This sample text illustrates the current settings. "
-           "You may edit it to test special characters.");
-    d->sampleEdit->setWhatsThis(sampleEditWhatsThisText);
-
-    connect(this, SIGNAL(fontSelected(QFont)),
-            this, SLOT(_k_displaySample(QFont)));
-
-    splitter->addWidget(d->sampleEdit);
-    //
-    // Finished setting up the splitter.
-
-    //
-    // Finished setting up the chooser layout.
-
-    // lets initialize the display if possible
-    if (d->usingFixed) {
-        setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont), d->usingFixed);
-    } else {
-        setFont(QGuiApplication::font(), d->usingFixed);
-    }
-
-    // check or uncheck or gray out the "relative" checkbox
-    if (sizeIsRelativeState && d->sizeIsRelativeCheckBox) {
-        setSizeIsRelative(*sizeIsRelativeState);
-    }
-
-    // Set focus to the size list as this is the most commonly changed property
-    d->sizeListBox->setFocus();
+    d->init(flags, fontList, visibleListSize, sizeIsRelativeState);
 }
 
 KFontChooser::~KFontChooser()
@@ -413,6 +154,245 @@ KFontChooser::~KFontChooser()
     delete d;
 }
 
+void KFontChooser::Private::init(const DisplayFlags &flags, const QStringList &fontList,
+                                 int visibleListSize, Qt::CheckState *sizeIsRelativeState)
+{
+    usingFixed = flags & FixedFontsOnly;
+
+    // The main layout is divided horizontally into a top part with
+    // the font attribute widgets (family, style, size) and a bottom
+    // part with a preview of the selected font
+    QVBoxLayout *mainLayout = new QVBoxLayout(q);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
+    auto *style = q->style();
+    const int sizeListBoxGap = style->pixelMetric(QStyle::PM_LayoutVerticalSpacing) / 2;
+    const int checkBoxGap = style->pixelMetric(QStyle::PM_LayoutHorizontalSpacing) / 2;
+
+    // Build the grid of font attribute widgets for the upper part of mainLayout
+    QWidget *page;
+    QGridLayout *gridLayout;
+    int row = flags & DisplayFrame ? 1 : 0;
+
+    if (flags & DisplayFrame) {
+        page = new QGroupBox(KFontChooser::tr("Requested Font", "@title:group"), q);
+        mainLayout->addWidget(page);
+        gridLayout = new QGridLayout(page);
+    } else {
+        page = new QWidget(q);
+        mainLayout->addWidget(page);
+        gridLayout = new QGridLayout(page);
+        gridLayout->setContentsMargins(0, 0, 0, 0);
+    }
+
+    // set up the family list view and checkbox
+    QHBoxLayout *familyLayout = new QHBoxLayout();
+    familyLayout->addSpacing(checkBoxGap);
+    if (flags & ShowDifferences) {
+        familyCheckbox = new QCheckBox(KFontChooser::tr("Font", "@option:check"), page);
+        familyLayout->addWidget(familyCheckbox, 0, Qt::AlignLeft);
+        familyLabel = nullptr;
+    } else {
+        familyCheckbox = nullptr;
+        familyLabel = new QLabel(KFontChooser::tr("Font:", "@label"), page);
+        familyLayout->addWidget(familyLabel, 1, Qt::AlignLeft);
+    }
+    gridLayout->addLayout(familyLayout, row, 0);
+
+    ++row;
+
+    familyListBox = new QListWidget(page);
+    gridLayout->addWidget(familyListBox, row, 0);
+
+    connect(familyListBox, &QListWidget::currentTextChanged, [this](const QString &family) {
+        _k_family_chosen_slot(family);
+    });
+
+    if (flags & ShowDifferences) {
+        familyListBox->setEnabled(false);
+        connect(familyCheckbox, &QAbstractButton::toggled, familyListBox, &QWidget::setEnabled);
+    }
+
+    if (!fontList.isEmpty()) {
+        setFamilyBoxItems(fontList);
+    } else {
+        fillFamilyListBox(flags & FixedFontsOnly);
+    }
+
+    familyListBox->setMinimumWidth(minimumListWidth(familyListBox));
+    familyListBox->setMinimumHeight(minimumListHeight(familyListBox, visibleListSize));
+
+
+    // set up the sytle list view and checkbox
+    row = flags & DisplayFrame ? 1 : 0;
+    QHBoxLayout *styleLayout = new QHBoxLayout();
+    if (flags & ShowDifferences) {
+        styleCheckbox = new QCheckBox(KFontChooser::tr("Font style", "@option:check"), page);
+        styleLayout->addWidget(styleCheckbox, 0, Qt::AlignLeft);
+        styleLabel = nullptr;
+    } else {
+        styleCheckbox = nullptr;
+        styleLabel = new QLabel(KFontChooser::tr("Font style:", "@label"), page);
+        styleLayout->addWidget(styleLabel, 1, Qt::AlignLeft);
+    }
+    styleLayout->addSpacing(checkBoxGap);
+    gridLayout->addLayout(styleLayout, row, 1);
+
+    ++row;
+
+    styleListBox = new QListWidget(page);
+    gridLayout->addWidget(styleListBox, row, 1);
+
+    // Populate usual styles, to determine minimum list width;
+    // will be replaced later with correct styles.
+    styleListBox->addItem(KFontChooser::tr("Normal", "@item font"));
+    styleListBox->addItem(KFontChooser::tr("Italic", "@item font"));
+    styleListBox->addItem(KFontChooser::tr("Oblique", "@item font"));
+    styleListBox->addItem(KFontChooser::tr("Bold", "@item font"));
+    styleListBox->addItem(KFontChooser::tr("Bold Italic", "@item font"));
+    styleListBox->setMinimumWidth(minimumListWidth(styleListBox));
+    styleListBox->setMinimumHeight(minimumListHeight(styleListBox, visibleListSize));
+
+    connect(styleListBox, &QListWidget::currentTextChanged, [this](const QString &style) {
+        _k_style_chosen_slot(style);
+    });
+
+    if (flags & ShowDifferences) {
+        styleListBox->setEnabled(false);
+        connect(styleCheckbox, &QAbstractButton::toggled, styleListBox, &QWidget::setEnabled);
+    }
+
+    // set the the size list view / font size spinbox; and the font size checkbox
+    row = flags & DisplayFrame ? 1 : 0;
+    QHBoxLayout *sizeLayout = new QHBoxLayout();
+    if (flags & ShowDifferences) {
+        sizeCheckbox = new QCheckBox(KFontChooser::tr("Size", "@option:check"), page);
+        sizeLayout->addWidget(sizeCheckbox, 0, Qt::AlignLeft);
+        sizeLabel = nullptr;
+    } else {
+        sizeCheckbox = nullptr;
+        sizeLabel = new QLabel(KFontChooser::tr("Size:", "@label:listbox Font size"), page);
+        sizeLayout->addWidget(sizeLabel, 1, Qt::AlignLeft);
+    }
+    sizeLayout->addSpacing(checkBoxGap);
+    sizeLayout->addSpacing(checkBoxGap);   // prevent label from eating border
+    gridLayout->addLayout(sizeLayout, row, 2);
+
+    ++row;
+
+    sizeListBox = new QListWidget(page);
+    sizeOfFont = new QDoubleSpinBox(page);
+    sizeOfFont->setMinimum(4);
+    sizeOfFont->setMaximum(512);
+    sizeOfFont->setDecimals(1);
+    sizeOfFont->setSingleStep(1);
+
+    if (sizeIsRelativeState) {
+        QString sizeIsRelativeCBText =
+            KFontChooser::tr("Relative", "@item font size");
+        QString sizeIsRelativeCBToolTipText =
+            KFontChooser::tr("Font size<br /><i>fixed</i> or <i>relative</i><br />to environment", "@info:tooltip");
+        QString sizeIsRelativeCBWhatsThisText =
+            KFontChooser::tr("Here you can switch between fixed font size and font size "
+               "to be calculated dynamically and adjusted to changing "
+               "environment (e.g. widget dimensions, paper size).", "@info:whatsthis");
+        sizeIsRelativeCheckBox = new QCheckBox(sizeIsRelativeCBText, page);
+        sizeIsRelativeCheckBox->setTristate(flags & ShowDifferences);
+        QGridLayout *sizeLayout2 = new QGridLayout();
+        sizeLayout2->setVerticalSpacing(sizeListBoxGap);
+        gridLayout->addLayout(sizeLayout2, row, 2);
+        sizeLayout2->setColumnStretch(1, 1);   // to prevent text from eating the right border
+        sizeLayout2->addWidget(sizeOfFont, 0, 0, 1, 2);
+        sizeLayout2->addWidget(sizeListBox, 1, 0, 1, 2);
+        sizeLayout2->addWidget(sizeIsRelativeCheckBox, 2, 0, Qt::AlignLeft);
+        sizeIsRelativeCheckBox->setWhatsThis(sizeIsRelativeCBWhatsThisText);
+        sizeIsRelativeCheckBox->setToolTip(sizeIsRelativeCBToolTipText);
+    } else {
+        sizeIsRelativeCheckBox = nullptr;
+        QGridLayout *sizeLayout2 = new QGridLayout();
+        sizeLayout2->setVerticalSpacing(sizeListBoxGap);
+        gridLayout->addLayout(sizeLayout2, row, 2);
+        sizeLayout2->addWidget(sizeOfFont, 0, 0);
+        sizeLayout2->addWidget(sizeListBox, 1, 0);
+    }
+
+    // Populate with usual sizes, to determine minimum list width;
+    // will be replaced later with correct sizes.
+    fillSizeList();
+    sizeListBox->setMinimumWidth(minimumListWidth(sizeListBox) + sizeListBox->fontMetrics().maxWidth());
+    sizeListBox->setMinimumHeight(minimumListHeight(sizeListBox, visibleListSize));
+
+    connect(sizeOfFont, QOverload<double>::of(&QDoubleSpinBox::valueChanged), [this](const double size) {
+        _k_size_value_slot(size);
+    });
+
+    connect(sizeListBox, &QListWidget::currentTextChanged, [this](const QString &size) {
+        _k_size_chosen_slot(size);
+    });
+
+    if (flags & ShowDifferences) {
+        sizeListBox->setEnabled(false);
+        sizeOfFont->setEnabled(false);
+        connect(sizeCheckbox, &QAbstractButton::toggled, sizeListBox, &QWidget::setEnabled);
+        connect(sizeCheckbox, &QAbstractButton::toggled, sizeOfFont, &QWidget::setEnabled);
+    }
+
+    // Add the font preview into the lower part of mainLayout
+    sampleEdit = new QTextEdit(page);
+    sampleEdit->setAcceptRichText(false);
+    QFont tmpFont(q->font().family(), 64, QFont::Black);
+    sampleEdit->setFont(tmpFont);
+    sampleEdit->setMinimumHeight(sampleEdit->fontMetrics().lineSpacing());
+    // tr: A classical test phrase, with all letters of the English alphabet.
+    // Replace it with a sample text in your language, such that it is
+    // representative of language's writing system.
+    // If you wish, you can input several lines of text separated by \n.
+    q->setSampleText(KFontChooser::tr("The Quick Brown Fox Jumps Over The Lazy Dog"));
+    sampleEdit->setTextCursor(QTextCursor(sampleEdit->document()));
+    QString sampleEditWhatsThisText =
+        KFontChooser::tr("This sample text illustrates the current settings. "
+           "You may edit it to test special characters.", "@info:whatsthis");
+    sampleEdit->setWhatsThis(sampleEditWhatsThisText);
+
+    connect(q, &KFontChooser::fontSelected, q, [this](const QFont &font) {
+        _k_displaySample(font);
+    });
+
+    mainLayout->addWidget(sampleEdit);
+
+    // If the calling app sets FixedFontsOnly, respect its decision
+    if (!usingFixed) {
+        // Add a checkbox to toggle showing only monospace/fixed-width fonts
+        onlyFixedCheckbox = new QCheckBox(KFontChooser::tr("Show only monospaced fonts", "@option:check"));
+        onlyFixedCheckbox->setChecked(usingFixed);
+
+        connect(onlyFixedCheckbox, &QAbstractButton::toggled, q, [this](const bool state) {
+            q->setFont(selFont, state);
+        });
+
+        if (flags & ShowDifferences) { // In this mode follow the state of the familyCheckbox
+            onlyFixedCheckbox->setEnabled(false);
+            connect(familyCheckbox, &QAbstractButton::toggled, onlyFixedCheckbox, &QWidget::setEnabled);
+        }
+        mainLayout->addWidget(onlyFixedCheckbox);
+    }
+    // Finished setting up the chooser layout
+
+    // lets initialize the display if possible
+    if (usingFixed) {
+        q->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont), true);
+    } else {
+        q->setFont(QGuiApplication::font(), false);
+    }
+
+    // check or uncheck or gray out the "relative" checkbox
+    if (sizeIsRelativeState && sizeIsRelativeCheckBox) {
+        q->setSizeIsRelative(*sizeIsRelativeState);
+    }
+
+    // Set focus to the size list as this is the most commonly changed property
+    sizeListBox->setFocus();
+}
+
 void KFontChooser::setColor(const QColor &col)
 {
     d->m_palette.setColor(QPalette::Active, QPalette::Text, col);
@@ -535,14 +515,6 @@ QFont KFontChooser::font() const
     return d->selFont;
 }
 
-void KFontChooser::Private::_k_toggled_checkbox()
-{
-    familyListBox->setEnabled(familyCheckbox->isChecked());
-    styleListBox->setEnabled(styleCheckbox->isChecked());
-    sizeListBox->setEnabled(sizeCheckbox->isChecked());
-    sizeOfFont->setEnabled(sizeCheckbox->isChecked());
-}
-
 void KFontChooser::Private::_k_family_chosen_slot(const QString &family)
 {
     if (!signalsAllowed) {
@@ -574,7 +546,9 @@ void KFontChooser::Private::_k_family_chosen_slot(const QString &family)
     QStringList filteredStyles;
     qtStyles.clear();
     styleIDs.clear();
-    Q_FOREACH (const QString &style, styles) {
+
+    const QStringList origStyles = styles;
+    for (const QString &style : origStyles) {
         // Sometimes the font database will report an invalid style,
         // that falls back back to another when set.
         // Remove such styles, by checking set/get round-trip.
@@ -832,12 +806,8 @@ qreal KFontChooser::Private::setupSizeListBox(const QString &family, const QStri
 {
     QFontDatabase dbase;
     QList<qreal> sizes;
-    if (dbase.isSmoothlyScalable(family, style)) {
-        // A vector font.
-        //>sampleEdit->setPaletteBackgroundPixmap( VectorPixmap ); // TODO
-    } else {
-        // A bitmap font.
-        //sampleEdit->setPaletteBackgroundPixmap( BitmapPixmap ); // TODO
+    const bool smoothlyScalable = dbase.isSmoothlyScalable(family, style);
+    if (!smoothlyScalable) {
         const QList<int> smoothSizes = dbase.smoothSizes(family, style);
         for (int size : smoothSizes) {
             sizes.append(size);
@@ -849,9 +819,8 @@ qreal KFontChooser::Private::setupSizeListBox(const QString &family, const QStri
     qreal bestFitSize = fillSizeList(sizes);
 
     // Set the best fit size as current in the listbox if available.
-    const QList<QListWidgetItem *> selectedSizeList =
-        sizeListBox->findItems(formatFontSize(bestFitSize),
-                               Qt::MatchExactly);
+    const QList<QListWidgetItem *> selectedSizeList = sizeListBox->findItems(
+                                                        formatFontSize(bestFitSize), Qt::MatchExactly);
     if (!selectedSizeList.isEmpty()) {
         sizeListBox->setCurrentItem(selectedSizeList.first());
     }
@@ -957,18 +926,18 @@ void KFontChooser::getFontList(QStringList &list, uint fontListCriteria)
     // if we have criteria; then check fonts before adding
     if (fontListCriteria) {
         QStringList lstFonts;
-        for (QStringList::const_iterator it = lstSys.constBegin(); it != lstSys.constEnd(); ++it) {
-            if ((fontListCriteria & FixedWidthFonts) > 0 && !dbase.isFixedPitch(*it)) {
+        for (const QString &family : qAsConst(lstSys)) {
+            if ((fontListCriteria & FixedWidthFonts) > 0 && !dbase.isFixedPitch(family)) {
                 continue;
             }
             if (((fontListCriteria & (SmoothScalableFonts | ScalableFonts)) == ScalableFonts) &&
-                    !dbase.isBitmapScalable(*it)) {
+                    !dbase.isBitmapScalable(family)) {
                 continue;
             }
-            if ((fontListCriteria & SmoothScalableFonts) > 0 && !dbase.isSmoothlyScalable(*it)) {
+            if ((fontListCriteria & SmoothScalableFonts) > 0 && !dbase.isSmoothlyScalable(family)) {
                 continue;
             }
-            lstFonts.append(*it);
+            lstFonts.append(family);
         }
 
         if ((fontListCriteria & FixedWidthFonts) > 0) {
@@ -1013,10 +982,35 @@ void KFontChooser::Private::fillFamilyListBox(bool onlyFixedFonts)
 // Hence, construct custom style identifiers sufficient for the purpose.
 QString KFontChooser::Private::styleIdentifier(const QFont &font)
 {
+    const int weight = font.weight();
+    QString styleName = font.styleName();
+    // If the styleName property is empty and the weight is QFont::Normal, that
+    // could mean it's a "Regular"-like style with the styleName part stripped
+    // so that subsequent calls to setBold(true) can work properly (i.e. selecting
+    // the "Bold" style provided by the font itself) without resorting to font
+    // "emboldening" which looks ugly.
+    // See also KConfigGroupGui::writeEntryGui().
+    if (styleName.isEmpty() && weight == QFont::Normal) {
+        QFontDatabase fdb;
+        const QStringList styles = fdb.styles(font.family());
+        for (const QString &style : styles) {
+            // orderded by commonness, i.e. "Regular" is the most common
+            if (style == QLatin1String("Regular")
+                || style == QLatin1String("Normal")
+                || style == QLatin1String("Book")
+                || style == QLatin1String("Roman")) {
+                styleName = style;
+            } else {
+                // nothing more we can do
+            }
+        }
+    }
+
     const QChar comma(QLatin1Char(','));
-    return   QString::number(font.weight()) + comma
+    return   QString::number(weight) + comma
              + QString::number((int)font.style()) + comma
-             + QString::number(font.stretch());
+             + QString::number(font.stretch()) + comma
+             + styleName;
 }
 
 #include "moc_kfontchooser.cpp"
