@@ -1,26 +1,8 @@
-/***************************************************************************
-                          kmultitabbar.cpp -  description
-                             -------------------
-    begin                :  2001
-    copyright            : (C) 2001,2002,2003 by Joseph Wenninger <jowenn@kde.org>
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001, 2002, 2003 Joseph Wenninger <jowenn@kde.org>
 
-/***************************************************************************
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
- ***************************************************************************/
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kmultitabbar.h"
 #include "kmultitabbar_p.h"
@@ -34,7 +16,7 @@
 
 #include <math.h>
 
-/**
+/*
  A bit of an overview about what's going on here:
  There are two sorts of things that can be in the tab bar: tabs and regular
  buttons. The former are managed by KMultiTabBarInternal, the later
@@ -158,6 +140,7 @@ KMultiTabBarButton::KMultiTabBarButton(const QIcon &icon, const QString &text,
     Q_UNUSED(d);
 }
 
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 72)
 KMultiTabBarButton::KMultiTabBarButton(const QPixmap &pic, const QString &text,
                                        int id, QWidget *parent)
     : QPushButton(QIcon(pic), text, parent), m_id(id), d(nullptr)
@@ -171,6 +154,7 @@ KMultiTabBarButton::KMultiTabBarButton(const QPixmap &pic, const QString &text,
     setAttribute(Qt::WA_LayoutUsesWidgetRect);
     Q_UNUSED(d);
 }
+#endif
 
 KMultiTabBarButton::~KMultiTabBarButton()
 {
@@ -238,6 +222,7 @@ KMultiTabBarTab::KMultiTabBarTab(const QIcon &icon, const QString &text,
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 }
 
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 72)
 KMultiTabBarTab::KMultiTabBarTab(const QPixmap &pic, const QString &text,
                                  int id, QWidget *parent,
                                  KMultiTabBar::KMultiTabBarPosition pos,
@@ -250,6 +235,7 @@ KMultiTabBarTab::KMultiTabBarTab(const QPixmap &pic, const QString &text,
     // shrink down to icon only, but prefer to show text if it's there
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 }
+#endif
 
 KMultiTabBarTab::~KMultiTabBarTab()
 {
@@ -267,11 +253,12 @@ void KMultiTabBarTab::setStyle(KMultiTabBar::KMultiTabBarStyle style)
     updateGeometry();
 }
 
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 72)
 QPixmap KMultiTabBarTab::iconPixmap() const
 {
-    int iconSize = style()->pixelMetric(QStyle::PM_SmallIconSize, nullptr, this);
-    return icon().pixmap(iconSize);
+    return icon().pixmap(iconSize());
 }
+#endif
 
 void KMultiTabBarTab::initStyleOption(QStyleOptionToolButton *opt) const
 {
@@ -279,7 +266,7 @@ void KMultiTabBarTab::initStyleOption(QStyleOptionToolButton *opt) const
 
     // Setup icon..
     if (!icon().isNull()) {
-        opt->iconSize = iconPixmap().size();
+        opt->iconSize = iconSize();
         opt->icon     = icon();
     }
 
@@ -289,12 +276,14 @@ void KMultiTabBarTab::initStyleOption(QStyleOptionToolButton *opt) const
     }
 
     opt->state |= QStyle::State_AutoRaise;
-    if (underMouse()) {
-        opt->state |= QStyle::State_MouseOver | QStyle::State_Raised;
+    if (!isChecked() && !isDown()) {
+        opt->state |= QStyle::State_Raised;
+    }
+    if (isDown()) {
+        opt->state |= QStyle::State_Sunken;
     }
-
     if (isChecked()) {
-        opt->state |= QStyle::State_Sunken | QStyle::State_On;
+        opt->state |= QStyle::State_On;
     }
 
     opt->font = font();
@@ -319,8 +308,7 @@ void KMultiTabBarTab::computeMargins(int *hMargin, int *vMargin) const
     QStyleOptionToolButton opt;
     initStyleOption(&opt);
 
-    QPixmap iconPix = iconPixmap();
-    QSize trialSize = iconPix.size() / iconPix.devicePixelRatio();
+    QSize trialSize = opt.iconSize;
     QSize expandSize = style()->sizeFromContents(QStyle::CT_ToolButton, &opt, trialSize, this);
 
     *hMargin = (expandSize.width()  - trialSize.width()) / 2;
@@ -337,8 +325,7 @@ QSize KMultiTabBarTab::computeSizeHint(bool withText) const
     computeMargins(&hMargin, &vMargin);
 
     // Compute interior size, starting from pixmap..
-    QPixmap iconPix = iconPixmap();
-    QSize size = iconPix.size() / iconPix.devicePixelRatio();
+    QSize size = opt.iconSize;
 
     // Always include text height in computation, to avoid resizing the minor direction
     // when expanding text..
@@ -372,17 +359,20 @@ void KMultiTabBarTab::setState(bool newState)
     updateGeometry();
 }
 
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 72)
 void KMultiTabBarTab::setIcon(const QString &icon)
 {
     const QIcon i = QIcon::fromTheme(icon);
-    const int iconSize = style()->pixelMetric(QStyle::PM_SmallIconSize, nullptr, this);
-    setIcon(i.pixmap(iconSize));
+    setIcon(i);
 }
+#endif
 
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 72)
 void KMultiTabBarTab::setIcon(const QPixmap &icon)
 {
     QPushButton::setIcon(icon);
 }
+#endif
 
 bool KMultiTabBarTab::shouldDrawText() const
 {
@@ -414,17 +404,16 @@ void KMultiTabBarTab::paintEvent(QPaintEvent *)
     // We first figure out how much room we have for the text, based on
     // icon size and margin, try to fit in by eliding, and perhaps
     // give up on drawing the text entirely if we're too short on room
-    QPixmap icon = iconPixmap();
     int textRoom = 0;
     int iconRoom = 0;
 
     QString t;
     if (shouldDrawText()) {
         if (isVertical()) {
-            iconRoom = icon.height() / icon.devicePixelRatio() + 2 * vMargin;
+            iconRoom = opt.iconSize.height() + 2 * vMargin;
             textRoom = height() - iconRoom - vMargin;
         } else {
-            iconRoom = icon.width() / icon.devicePixelRatio() + 2 * hMargin;
+            iconRoom = opt.iconSize.width() + 2 * hMargin;
             textRoom = width() - iconRoom - hMargin;
         }
 
@@ -437,11 +426,14 @@ void KMultiTabBarTab::paintEvent(QPaintEvent *)
         }
     }
 
+    const QIcon::Mode iconMode = (opt.state & QStyle::State_MouseOver) ? QIcon::Active : QIcon::Normal;
+    const QPixmap iconPixmap = icon().pixmap(opt.iconSize, iconMode, QIcon::On);
+
     // Label time.... Simple case: no text, so just plop down the icon right in the center
     // We only do this when the button never draws the text, to avoid jumps in icon position
     // when resizing
     if (!shouldDrawText()) {
-        style()->drawItemPixmap(&painter, rect(), Qt::AlignCenter | Qt::AlignVCenter, icon);
+        style()->drawItemPixmap(&painter, rect(), Qt::AlignCenter | Qt::AlignVCenter, iconPixmap);
         return;
     }
 
@@ -461,13 +453,17 @@ void KMultiTabBarTab::paintEvent(QPaintEvent *)
     }
     //alignFlags = Qt::AlignLeading | Qt::AlignVCenter;
 
+    const int iconXShift = (isChecked() || isDown()) ? style()->pixelMetric(QStyle::PM_ButtonShiftHorizontal, &opt, this) : 0;
+    const int iconYShift = (isChecked() || isDown()) ? style()->pixelMetric(QStyle::PM_ButtonShiftVertical, &opt, this) : 0;
     if (isVertical()) {
         if (bottomIcon) {
             labelArea = QRect(0, vMargin, width(), textRoom);
             iconArea  = QRect(0, vMargin + textRoom, width(), iconRoom);
+            iconArea.translate(iconYShift, -iconXShift);
         } else {
             labelArea = QRect(0, iconRoom, width(), textRoom);
             iconArea  = QRect(0, 0, width(), iconRoom);
+            iconArea.translate(-iconYShift, iconXShift);
         }
     } else {
         // Pretty simple --- depends only on RTL/LTR
@@ -478,9 +474,10 @@ void KMultiTabBarTab::paintEvent(QPaintEvent *)
             labelArea = QRect(iconRoom, 0, textRoom, height());
             iconArea  = QRect(0, 0, iconRoom, height());
         }
+        iconArea.translate(iconXShift, iconYShift);
     }
 
-    style()->drawItemPixmap(&painter, iconArea, Qt::AlignCenter | Qt::AlignVCenter, icon);
+    style()->drawItemPixmap(&painter, iconArea, Qt::AlignCenter | Qt::AlignVCenter, iconPixmap);
 
     if (t.isEmpty()) {
         return;
