@@ -1,33 +1,13 @@
-/***************************************************************************
-                          kmultitabbar.h -  description
-                             -------------------
-    begin                :  2001
-    copyright            : (C) 2001,2002,2003 by Joseph Wenninger <jowenn@kde.org>
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001, 2002, 2003 Joseph Wenninger <jowenn@kde.org>
 
-/***************************************************************************
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
- ***************************************************************************/
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef _KMultitabbar_h_
 #define _KMultitabbar_h_
 
-#include <QLayout>
 #include <QString>
-#include <QList>
 #include <QPushButton>
 
 #include <kwidgetsaddons_export.h>
@@ -89,7 +69,7 @@ public:
      * append  a new button to the button area. The button can later on be accessed with button(ID)
      * eg for connecting signals to it
      * @param icon a icon for the button
-     * @param id an arbitraty ID value. It will be emitted in the clicked signal for identifying the button
+     * @param id an arbitrary ID value. It will be emitted in the clicked signal for identifying the button
      *  if more than one button is connected to a signals.
      * @param popup A popup menu which should be displayed if the button is clicked
      * @param not_used_yet will be used for a popup text in the future
@@ -97,20 +77,21 @@ public:
      */
     int appendButton(const QIcon &icon, int id = -1, QMenu *popup = nullptr, const QString &not_used_yet = QString());
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 13)
     /**
      * append  a new button to the button area. The button can later on be accessed with button(ID)
      * eg for connecting signals to it
      *
-     * @deprecated since 5.13, use the appendButton() with QIcon
-     *
      * @param pic a pixmap for the button
      * @param id an arbitraty ID value. It will be emitted in the clicked signal for identifying the button
      *  if more than one button is connected to a signals.
      * @param popup A popup menu which should be displayed if the button is clicked
      * @param not_used_yet will be used for a popup text in the future
+     *
+     * @deprecated Since 5.13, use appendButton(const QIcon &, int, QMenu *, const QString &)
      */
-    KWIDGETSADDONS_DEPRECATED int appendButton(const QPixmap &pic, int id = -1, QMenu *popup = nullptr, const QString &not_used_yet = QString());
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 13, "Use KMultiTabBar::appendButton(const QIcon&, ...)")
+    int appendButton(const QPixmap &pic, int id = -1, QMenu *popup = nullptr, const QString &not_used_yet = QString());
 #endif
 
     /**
@@ -127,17 +108,18 @@ public:
      */
     int appendTab(const QIcon &icon, int id = -1, const QString &text = QString());
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 13)
     /**
      * append a new tab to the tab area. It can be accessed lateron with tabb(id);
      *
-     * @deprecated since 5.13, use the appendTab() with QIcon
-     *
      * @param pic a bitmap for the tab
      * @param id an arbitrary ID which can be used later on to identify the tab
      * @param text if a mode with text is used it will be the tab text, otherwise a mouse over hint
+     *
+     * @deprecated Since 5.13, use appendTab(const QIcon &, int, const QString &)
      */
-    KWIDGETSADDONS_DEPRECATED int appendTab(const QPixmap &pic, int id = -1, const QString &text = QString());
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 13, "Use KMultiTabBar::appendTab(const QIcon&, ...)")
+    int appendTab(const QPixmap &pic, int id = -1, const QString &text = QString());
 #endif
 
     /**
@@ -160,7 +142,7 @@ public:
     class KMultiTabBarButton *button(int id) const;
 
     /**
-     * get a pointer to a tab within the tab area, identiifed by its ID
+     * get a pointer to a tab within the tab area, identified by its ID
      */
     class KMultiTabBarTab *tab(int id) const;
 
@@ -224,13 +206,18 @@ protected:
     void showEvent(class QShowEvent *) override;
     void paintEvent(class QPaintEvent *) override;
 
-    /** Should not be created directly. Use KMultiTabBar::appendButton
-    */
+    /**
+     * Should not be created directly. Use KMultiTabBar::appendButton
+     */
     KMultiTabBarButton(const QIcon &icon, const QString &, int id, QWidget *parent);
 
-    /** Should not be created directly. Use KMultiTabBar::appendButton
-    */
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
+    /**
+     * Should not be created directly. Use KMultiTabBar::appendButton
+     */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 72, "Use overload with QIcon")
     KMultiTabBarButton(const QPixmap &pic, const QString &, int id, QWidget *parent);
+#endif
 private:
     friend class KMultiTabBar;
 
@@ -253,13 +240,13 @@ public:
 
 public Q_SLOTS:
     /**
-     * this is used internaly, but can be used by the user, if (s)he wants to
+     * this is used internally, but can be used by the user, if (s)he wants to
      * It the according call of KMultiTabBar is invoked though this modifications will be overwritten
      */
     void setPosition(KMultiTabBar::KMultiTabBarPosition);
 
     /**
-     * this is used internaly, but can be used by the user, if (s)he wants to
+     * this is used internally, but can be used by the user, if (s)he wants to
      * It the according call of KMultiTabBar is invoked though this modifications will be overwritten
      */
     void setStyle(KMultiTabBar::KMultiTabBarStyle);
@@ -270,8 +257,17 @@ public Q_SLOTS:
      */
     void setState(bool state);
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 72, "Use KMultiTabBar::setIcon(const QIcon&)")
     void setIcon(const QString &);
+#endif
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 72, "Use KMultiTabBar::setIcon(const QIcon&)")
     void setIcon(const QPixmap &);
+#endif
+public:
+    using KMultiTabBarButton::setIcon;
+
 protected:
     void paintEvent(QPaintEvent *) override;
 private:
@@ -282,7 +278,9 @@ private:
     QSize computeSizeHint(bool withText) const;
     bool shouldDrawText() const;
     bool isVertical()     const;
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
     QPixmap iconPixmap()  const;
+#endif
 
     void initStyleOption(QStyleOptionToolButton *opt) const;
 
@@ -292,11 +290,14 @@ private:
      */
     KMultiTabBarTab(const QIcon &icon, const QString &, int id, QWidget *parent,
                     KMultiTabBar::KMultiTabBarPosition pos, KMultiTabBar::KMultiTabBarStyle style);
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
     /**
      * This class should never be created except with the appendTab call of KMultiTabBar
      */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 72, "Use overload with QIcon")
     KMultiTabBarTab(const QPixmap &pic, const QString &, int id, QWidget *parent,
                     KMultiTabBar::KMultiTabBarPosition pos, KMultiTabBar::KMultiTabBarStyle style);
+#endif
     KMultiTabBarTabPrivate *const d;
 };
 
