@@ -1,20 +1,10 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2000 David Faure <faure@kde.org>
-   Copyright (C) 2007 Olivier Goffart <ogoffart at kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2007 Olivier Goffart <ogoffart at kde.org>
+    SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 #include "kpassworddialog.h"
 
@@ -36,9 +26,7 @@ class Q_DECL_HIDDEN KPasswordDialog::KPasswordDialogPrivate
 {
 public:
     KPasswordDialogPrivate(KPasswordDialog *q)
-        : q(q),
-          userEditCombo(nullptr),
-          commentRow(0)
+        : q(q)
     {}
 
     void actuallyAccept();
@@ -47,13 +35,13 @@ public:
     void updateFields();
     void init();
 
-    KPasswordDialog *q;
+    KPasswordDialog *const q;
     Ui_KPasswordDialog ui;
     QMap<QString, QString> knownLogins;
-    QComboBox *userEditCombo;
+    QComboBox *userEditCombo = nullptr;
     QIcon icon;
     KPasswordDialogFlags m_flags;
-    unsigned int commentRow;
+    unsigned int commentRow = 0;
 };
 
 KPasswordDialog::KPasswordDialog(QWidget *parent,
@@ -87,6 +75,18 @@ void KPasswordDialog::KPasswordDialogPrivate::init()
     ui.buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     ui.errorMessage->setHidden(true);
 
+    ui.userEditContextHelpButton->hide();
+    ui.userEditContextHelpButton->setFlat(true);
+    ui.userEditContextHelpButton->setIcon(QIcon::fromTheme(QStringLiteral("help-contextual")));
+    ui.userEditContextHelpButton->setText(QString());
+    const QString description = QApplication::translate("KPasswordDialog", "Show Contextual Help");
+    ui.userEditContextHelpButton->setAccessibleName(description);
+    ui.userEditContextHelpButton->setToolTip(description);
+    connect(ui.userEditContextHelpButton, &QPushButton::released, q, [this] {
+        QEvent ev(QEvent::WhatsThis);
+        qApp->sendEvent(ui.userEdit, &ev);
+    });
+
     // Row 4: Username field
     if (m_flags & KPasswordDialog::ShowUsernameLine) {
         ui.userEdit->setFocus();
@@ -424,4 +424,10 @@ QDialogButtonBox *KPasswordDialog::buttonBox() const
     return d->ui.buttonBox;
 }
 
+void KPasswordDialog::setUsernameContextHelp(const QString &help)
+{
+    d->ui.userEditContextHelpButton->setVisible(true);
+    d->ui.userEdit->setWhatsThis(help);
+}
+
 #include "moc_kpassworddialog.cpp"
