@@ -1,20 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2004 Antonio Larrosa <larrosa@kde.org
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2004 Antonio Larrosa <larrosa@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kpixmapregionselectordialog.h"
@@ -33,12 +21,12 @@ class Q_DECL_HIDDEN KPixmapRegionSelectorDialog::Private
 {
 public:
     Private(KPixmapRegionSelectorDialog *parent)
-        : pixmapSelectorWidget(nullptr), q(parent)
+        : q(parent)
     {
     }
 
-    KPixmapRegionSelectorWidget *pixmapSelectorWidget;
-    KPixmapRegionSelectorDialog *q;
+    KPixmapRegionSelectorWidget *pixmapSelectorWidget = nullptr;
+    KPixmapRegionSelectorDialog *const q;
 
     void init()
     {
@@ -51,11 +39,7 @@ public:
     {
         if (pixmapSelectorWidget) {
             //Set maximum size for picture
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
             QScreen *screen = pixmapSelectorWidget->screen();
-#else
-            QScreen *screen = QGuiApplication::screenAt(pixmapSelectorWidget->geometry().center());
-#endif
             if (screen) {
                 const QRect screenGeometry = screen->availableGeometry();
                 pixmapSelectorWidget->setMaximumWidgetSize(
@@ -69,11 +53,11 @@ KPixmapRegionSelectorDialog::KPixmapRegionSelectorDialog(QWidget *parent)
     : QDialog(parent),
       d(new Private(this))
 {
-    setWindowTitle(tr("Select Region of Image"));
+    setWindowTitle(tr("Select Region of Image", "@title:window"));
 
     QVBoxLayout *boxLayout = new QVBoxLayout(this);
 
-    QLabel *label = new QLabel(tr("Please click and drag on the image to select the region of interest:"), this);
+    QLabel *label = new QLabel(tr("Please click and drag on the image to select the region of interest:", "@label:chooser"), this);
     d->pixmapSelectorWidget = new KPixmapRegionSelectorWidget(this);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
