@@ -1,22 +1,10 @@
 /*  -*- C++ -*-
     This file is part of the KDE libraries
-    Copyright (C) 1997 Tim D. Gilman (tdgilman@best.org)
-              (C) 1998-2001 Mirko Boehm (mirko@kde.org)
-              (C) 2007 John Layt <john@layt.net>
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+    SPDX-FileCopyrightText: 1997 Tim D. Gilman <tdgilman@best.org>
+    SPDX-FileCopyrightText: 1998-2001 Mirko Boehm <mirko@kde.org>
+    SPDX-FileCopyrightText: 2007 John Layt <john@layt.net>
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPOPUPFRAME_H
@@ -49,7 +37,8 @@ protected:
 public Q_SLOTS:
     /**
      * Close the popup window. This is called from the main widget, usually.
-     * @p r is the result returned from exec().
+     *
+     * @param r is the result returned from exec()
      */
     void close(int r);
 
@@ -66,7 +55,7 @@ public:
 
     /**
      * Set the main widget. You cannot set the main widget from the constructor,
-     * since it must be a child of the frame itselfes.
+     * since it must be a child of the frame itself.
      * Be careful: the size is set to the main widgets size. It is up to you to
      * set the main widgets correct size before setting it as the main
      * widget.
