@@ -1,20 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1998 Jörg Habenicht (j.habenicht@europemail.com)
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1998 Jörg Habenicht <j.habenicht@europemail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kruler.h"
@@ -71,7 +59,7 @@
 # include <qdatetime.h>
 #endif
 
-class KRuler::KRulerPrivate
+class Q_DECL_HIDDEN KRuler::KRulerPrivate
 {
 public:
     int  endOffset_length;  /* marks the offset at the end of the ruler
@@ -154,10 +142,6 @@ KRuler::KRuler(Qt::Orientation orient, int widgetWidth,
 
 void KRuler::initWidget(Qt::Orientation orientation)
 {
-#ifdef __GNUC__
-#warning FIXME setFrameStyle(WinPanel | Raised);
-#endif
-
     d->showpointer = INIT_SHOW_POINTER;
     d->showEndL = INIT_SHOW_END_LABEL;
     d->lengthFix = INIT_LENGTH_FIX;
@@ -182,7 +166,7 @@ KRuler::~KRuler()
     delete d;
 }
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 0)
 void
 KRuler::setMinValue(int value)
 {
@@ -190,7 +174,7 @@ KRuler::setMinValue(int value)
 }
 #endif
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 0)
 int
 KRuler::minValue() const
 {
@@ -198,7 +182,7 @@ KRuler::minValue() const
 }
 #endif
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 0)
 void
 KRuler::setMaxValue(int value)
 {
@@ -206,7 +190,7 @@ KRuler::setMaxValue(int value)
 }
 #endif
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 0)
 int
 KRuler::maxValue() const
 {
@@ -364,7 +348,7 @@ KRuler::showPointer() const
     return d->showpointer;
 }
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 0)
 void
 KRuler::setFrameStyle(int)
 {
@@ -396,7 +380,7 @@ KRuler::setEndLabel(const QString &label)
         QFont font = this->font();
         font.setPointSize(LABEL_SIZE);
         QFontMetrics fm(font);
-        d->fontWidth = fm.width(d->endlabel);
+        d->fontWidth = fm.horizontalAdvance(d->endlabel);
     }
     update(contentsRect());
 }
@@ -686,7 +670,7 @@ KRuler::paintEvent(QPaintEvent * /*e*/)
 #endif
                 p.drawText(END_LABEL_X, END_LABEL_Y, d->endlabel);
             }
-            p.resetMatrix();
+            p.resetTransform();
         }
 
         // draw the tiny marks
