@@ -1,25 +1,12 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1997 Martin Jones (mjones@kde.org)
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1997 Martin Jones <mjones@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kselector.h"
 
-#include <QImage>
 #include <QPainter>
 #include <QPaintEvent>
 #include <QPixmap>
@@ -37,14 +24,8 @@
 class Q_DECL_HIDDEN KSelector::Private
 {
 public:
-    Private()
-    {
-        arrowPE = QStyle::PE_IndicatorArrowLeft;
-        m_indent = true;
-    }
-
-    bool m_indent;
-    QStyle::PrimitiveElement arrowPE;
+    bool m_indent = true;
+    QStyle::PrimitiveElement arrowPE = QStyle::PE_IndicatorArrowLeft;
 };
 
 class Q_DECL_HIDDEN KGradientSelector::KGradientSelectorPrivate
@@ -129,8 +110,6 @@ void KSelector::paintEvent(QPaintEvent *)
 
     drawContents(&painter);
 
-    QBrush brush;
-
     QPoint pos = calcArrowPos(value());
     drawArrow(&painter, pos);
 
@@ -171,7 +150,7 @@ void KSelector::mouseReleaseEvent(QMouseEvent *e)
 
 void KSelector::wheelEvent(QWheelEvent *e)
 {
-    int val = value() + e->delta() / 120;
+    int val = value() + e->angleDelta().y() / 120;
     setSliderDown(true);
     setValue(val);
     setSliderDown(false);
@@ -263,17 +242,13 @@ Qt::ArrowType KSelector::arrowDirection() const
     switch (d->arrowPE) {
     case QStyle::PE_IndicatorArrowUp:
         return Qt::UpArrow;
-        break;
     case QStyle::PE_IndicatorArrowDown:
         return Qt::DownArrow;
-        break;
     case QStyle::PE_IndicatorArrowRight:
         return Qt::RightArrow;
-        break;
     case QStyle::PE_IndicatorArrowLeft:
     default:
         return Qt::LeftArrow;
-        break;
     }
 }
 
@@ -340,14 +315,14 @@ void KGradientSelector::drawContents(QPainter *painter)
     if (orientation() == Qt::Vertical) {
         int yPos = contentsRect().top() + painter->fontMetrics().ascent() + 2;
         int xPos = contentsRect().left() + (contentsRect().width() -
-                                            painter->fontMetrics().width(d->text2)) / 2;
+                                            painter->fontMetrics().horizontalAdvance(d->text2)) / 2;
         QPen pen(qGray(firstColor().rgb()) > 180 ? Qt::black : Qt::white);
         painter->setPen(pen);
         painter->drawText(xPos, yPos, d->text2);
 
         yPos = contentsRect().bottom() - painter->fontMetrics().descent() - 2;
         xPos = contentsRect().left() + (contentsRect().width() -
-                                        painter->fontMetrics().width(d->text1)) / 2;
+                                        painter->fontMetrics().horizontalAdvance(d->text1)) / 2;
         pen.setColor(qGray(secondColor().rgb()) > 180 ? Qt::black : Qt::white);
         painter->setPen(pen);
         painter->drawText(xPos, yPos, d->text1);
@@ -361,7 +336,7 @@ void KGradientSelector::drawContents(QPainter *painter)
         pen.setColor(qGray(secondColor().rgb()) > 180 ? Qt::black : Qt::white);
         painter->setPen(pen);
         painter->drawText(contentsRect().right() -
-                          painter->fontMetrics().width(d->text2) - 2, yPos, d->text2);
+                          painter->fontMetrics().horizontalAdvance(d->text2) - 2, yPos, d->text2);
     }
 }
 
