@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2000 Ronny Standtke <Ronny.Standtke@gmx.de>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Ronny Standtke <Ronny.Standtke@gmx.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "ksqueezedtextlabel.h"
@@ -23,7 +12,7 @@
 #include <QMenu>
 #include <QClipboard>
 #include <QApplication>
-#include <QMimeData>
+#include <QRegularExpression>
 #include <QTextDocument>
 
 class KSqueezedTextLabelPrivate
@@ -78,7 +67,7 @@ QSize KSqueezedTextLabel::sizeHint() const
 {
     int maxWidth = QApplication::desktop()->screenGeometry(this).width() * 3 / 4;
     QFontMetrics fm(fontMetrics());
-    int textWidth = fm.width(d->fullText);
+    int textWidth = fm.boundingRect(d->fullText).width();
     if (textWidth > maxWidth) {
         textWidth = maxWidth;
     }
@@ -116,8 +105,10 @@ void KSqueezedTextLabel::squeezeTextToLabel()
     const int labelWidth = contentsRect().width();
     QStringList squeezedLines;
     bool squeezed = false;
-    Q_FOREACH (const QString &line, d->fullText.split(QLatin1Char('\n'))) {
-        int lineWidth = fm.width(line);
+    const auto textLines = d->fullText.split(QLatin1Char('\n'));
+    squeezedLines.reserve(textLines.size());
+    for (const QString &line : textLines) {
+        int lineWidth = fm.boundingRect(line).width();
         if (lineWidth > labelWidth) {
             squeezed = true;
             squeezedLines << fm.elidedText(line, d->elideMode, labelWidth);
@@ -127,7 +118,7 @@ void KSqueezedTextLabel::squeezeTextToLabel()
     }
 
     if (squeezed) {
-        QLabel::setText(squeezedLines.join(QStringLiteral("\n")));
+        QLabel::setText(squeezedLines.join(QLatin1Char('\n')));
         setToolTip(d->fullText);
     } else {
         QLabel::setText(d->fullText);
@@ -144,7 +135,7 @@ QRect KSqueezedTextLabel::contentsRect() const
         if (frameWidth() == 0) {
             indent = 0;
         } else {
-            indent = fontMetrics().width(QLatin1Char('x')) / 2 - margin;
+            indent = fontMetrics().horizontalAdvance(QLatin1Char('x')) / 2 - margin;
         }
     }
 
@@ -212,7 +203,7 @@ void KSqueezedTextLabel::contextMenuEvent(QContextMenuEvent *ev)
     if (isSqueezed()) {
         QMenu menu(this);
 
-        QAction *act = new QAction(tr("&Copy Full Text"), &menu);
+        QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), tr("&Copy Full Text", "@action:inmenu"), &menu);
         connect(act, &QAction::triggered, this, [this]() { d->_k_copyFullText(); });
         menu.addAction(act);
 
@@ -225,7 +216,6 @@ void KSqueezedTextLabel::contextMenuEvent(QContextMenuEvent *ev)
 
 void KSqueezedTextLabel::mouseReleaseEvent(QMouseEvent *ev)
 {
-#if QT_VERSION >= 0x040700
     if (QApplication::clipboard()->supportsSelection() &&
             textInteractionFlags() != Qt::NoTextInteraction &&
             ev->button() == Qt::LeftButton &&
@@ -246,16 +236,14 @@ void KSqueezedTextLabel::mouseReleaseEvent(QMouseEvent *ev)
             // Strip markup tags
             if (textFormat() == Qt::RichText
                     || (textFormat() == Qt::AutoText && Qt::mightBeRichText(txt))) {
-                txt.replace(QRegExp(QStringLiteral("<[^>]*>")), QStringLiteral(""));
+                txt.remove(QRegularExpression(QStringLiteral("<[^>]*>")));
                 // account for stripped characters
                 charsAfterSelection -= d->fullText.length() - txt.length();
             }
             txt = txt.mid(selectionStart(), txt.length() - start - charsAfterSelection);
         }
         QApplication::clipboard()->setText(txt, QClipboard::Selection);
-    } else
-#endif
-    {
+    } else {
         QLabel::mouseReleaseEvent(ev);
     }
 }
