@@ -1,23 +1,12 @@
 /*
- * This file is part of the KDE project
- * Copyright (C) 2008 Fredrik Höglund <fredrik@kde.org>
- * Copyright (C) 2008 Konstantin Heil <konst.heil@stud.uni-heidelberg.de>
- * Copyright (C) 2009 Peter Penz <peter.penz@gmx.at>
- * Copyright (C) 2017 Elvis Angelaccio <elvis.angelaccio@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- */
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2008 Fredrik Höglund <fredrik@kde.org>
+    SPDX-FileCopyrightText: 2008 Konstantin Heil <konst.heil@stud.uni-heidelberg.de>
+    SPDX-FileCopyrightText: 2009 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2017 Elvis Angelaccio <elvis.angelaccio@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "ktooltipwidget.h"
 
@@ -33,10 +22,7 @@ class Q_DECL_HIDDEN KToolTipWidget::KToolTipWidgetPrivate
 {
 public:
     KToolTipWidgetPrivate(KToolTipWidget *parent)
-        : q(parent),
-          layout(nullptr),
-          content(nullptr),
-          contentParent(nullptr)
+        : q(parent)
     {}
 
     void init();
@@ -47,11 +33,11 @@ public:
     void restoreParent();
     QPoint centerBelow(const QRect &rect, QScreen *screen) const;
 
-    KToolTipWidget *q;
+    KToolTipWidget *const q;
     QTimer hideTimer;
-    QVBoxLayout *layout;
-    QWidget *content;
-    QWidget *contentParent;
+    QVBoxLayout *layout = nullptr;
+    QWidget *content = nullptr;
+    QWidget *contentParent = nullptr;
 };
 
 void KToolTipWidget::KToolTipWidgetPrivate::init()
@@ -179,10 +165,12 @@ void KToolTipWidget::showAt(const QPoint &pos, QWidget *content, QWindow *transi
 void KToolTipWidget::showBelow(const QRect &rect, QWidget *content, QWindow *transientParent)
 {
     d->addWidget(content);
-    const QSize marginSize{
-        2 * content->style()->pixelMetric(QStyle::PM_DefaultTopLevelMargin),
-        2 * content->style()->pixelMetric(QStyle::PM_DefaultTopLevelMargin)};
-    content->setMaximumSize(transientParent->screen()->geometry().size() - marginSize);
+
+    const auto contentMargins = layout()->contentsMargins();
+    const QSize screenSize = transientParent->screen()->geometry().size();
+
+    content->setMaximumSize(screenSize.shrunkBy(contentMargins));
+
     d->show(d->centerBelow(rect, transientParent->screen()), transientParent);
 }
 
@@ -237,7 +225,7 @@ void KToolTipWidget::paintEvent(QPaintEvent *event)
     QStylePainter painter(this);
     painter.setClipRegion(event->region());
     QStyleOptionFrame option;
-    option.init(this);
+    option.initFrom(this);
     painter.drawPrimitive(QStyle::PE_PanelTipLabel, option);
     painter.end();
 
